[![Documentation Status](https://readthedocs.org/projects/geomappy/badge/?version=latest)](https://geomappy.readthedocs.io/en/latest/?badge=latest)

This package aims to provide a quick interface to create publication quality maps. It combines the plotting of both
raster and polygon data on a basemap (based on cartopy) and integrates its functionality into geopandas and rioxarray.
